%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Funcion:                    AGV
%  Description:             Does one programm step on all AGVs
%  Dependencies:       none                                             
%  Author:                      Stefan Bracher
%  Date:                         17.03.2007
%  Status:                       REL
%  
%  Syntaxe:                   [o, d_i, agv_list]=agv(o, d_i, agv_list, min_v, max_v, agv_v)  
%                                                                    
%  Input:                          o:                          Obstacle map
%                                      d_i:                       Pheromone maps
%                                                                   (2+n)D Matrix, n=number of different pheromones
%                                      agv_list:               List of all the agvs. One agv per line.
%                                                                    [x, y, status, idle time]
%                                                                    x, y: Position                                                                   
%                                                                    status:   1= idle: ready to pick up a job
%                                                                                   2= busy:job to bring to machine
%                                                                                   3=  job to bring to unload bay
%                                                                    idle time: Time running around with no load                 
 %                                     min_v:                  The minimal pheromone value at a point
 %                                     max_v:                  The maximal pheromone value at a point
%                                      agv_v:                   Speed of the AGVs [m/sec]                
%        
%  Output:                     o:                              Updated Obstacle map
%                                   d_i:                            Updated Pheromone maps
%                                   agv_list:                   Updatet AGV list
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [o, d_i, agv_list]=agv(o, d_i, agv_list, min_v, max_v, agv_v)

size_d_i=size(d_i);                                             % Get the dimensions of the floor
size_pos=size(agv_list);                                    % Get the length of the AGV list
agv_n=size_pos(1);                                            % -> Number of agvs


for i=1:agv_n                                                           % For every AGV
     if (agv_list(i, 3)==1)                                           % If AGV is idle
         agv_list(i, 4)=agv_list(i, 4)+1/agv_v ;           % increase idle time
     end
  
    old_pos=agv_list(i, 1:2);                                   % old coordonates of the agv
    
    % RULE 1: IF NO GRANDIENT PRESENT, DO RANDOM WALK
    % Random direction
    if (round(rand)==1)                                     % move along x
        go_to=old_pos+[1, 0];                                          % +x
        if (round(rand)==1)
           go_to=old_pos+[-1, 0];                                     % -x   
        end
    else                                                               % move along y
        go_to=old_pos+[0, 1];                                          % +y
        if (round(rand)==1)
           go_to=old_pos+[0, -1];                                     % -y 
        end
    end
  
    % RULE 2 FOLLOW THE GRADIENT OF YOUR CURRENT STATUS
    d_i_go_to=d_i(go_to(1), go_to(2), agv_list(i, 3));                      % d_i Pheromone content at the designatet new position
    d_i_alt=d_i(old_pos(1)+1, old_pos(2), agv_list(i, 3));              % An alternative spot
    if ((d_i_alt>d_i_go_to)&&(o(old_pos(1)+1, old_pos(2))==0)) % If there is more pheromone and no wall
        go_to=old_pos+[1, 0];                                                                  % change destination
        d_i_go_to=d_i(go_to(1), go_to(2), agv_list(i, 3));                   % d_i Pheromone content at the designatet new position
    end
        
    d_i_alt=d_i(old_pos(1)-1, old_pos(2), agv_list(i, 3));              % An alternative spot
    if ((d_i_alt>d_i_go_to)&&(o(old_pos(1)-1, old_pos(2))==0)) % If there is more pheromone and no wall
        go_to=old_pos+[-1, 0];                                                               % change destination
        d_i_go_to=d_i(go_to(1), go_to(2), agv_list(i, 3));                 % d_i Pheromone content at the designatet new position
   end
           
   d_i_alt=d_i(old_pos(1), old_pos(2)+1, agv_list(i, 3));              % An alternative spot
   if ((d_i_alt>d_i_go_to)&&(o(old_pos(1), old_pos(2)+1)==0))  % If there is more pheromone and no wall
        go_to=old_pos+[0, 1];                                                                 % change destination
        d_i_go_to=d_i(go_to(1), go_to(2), agv_list(i, 3));                 % d_i Pheromone content at the designatet new position
    end
            
    d_i_alt=d_i(old_pos(1), old_pos(2)-1, agv_list(i, 3));                 % An alternative spot
    if ((d_i_alt>d_i_go_to)&&(o(old_pos(1), old_pos(2)-1)==0))    % If there is more pheromone and no wall
        go_to=old_pos+[0, -1];                                                                  % change destination
        d_i_go_to=d_i(go_to(1), go_to(2), agv_list(i, 3));                    % d_i Pheromone content at the designatet new position
    end
                
    % RULE 3: AVOID OBSTACLES
    if (o(go_to(1), go_to(2))==0)                               % If on the target place is no obstavle
        agv_list(i, 1:2)=go_to;                                      % go there
        o(agv_list(i, 1), agv_list(i, 2))=1;                    % Drawing the AGV on the obstacle map
        o(old_pos(1), old_pos(2) )=0;                       % Freenng the old space
    end
    
    % RULE 4: DONT FLOCK (PUT AN ANTY PHEROMONE AROUND YOU)
       d_i(go_to(1)+1, go_to(2), agv_list(i, 3))=d_i(go_to(1)+1, go_to(2), agv_list(i, 3))-1/agv_v; % Decrease the pheromone
    if (d_i(go_to(1)+1, go_to(2), agv_list(i, 3))<min_v)    % Don't exeed minimal pheromone level
        d_i(go_to(1)+1, go_to(2), agv_list(i, 3))=min_v;
    end
    
         d_i(go_to(1)-1, go_to(2), agv_list(i, 3))=d_i(go_to(1)-1, go_to(2), agv_list(i, 3))-1/agv_v; % Decrease the pheromone
    if (d_i(go_to(1)-1, go_to(2), agv_list(i, 3))<min_v)    % Don't exeed minimal pheromone level
        d_i(go_to(1)-1, go_to(2), agv_list(i, 3))=min_v;
    end
    
         d_i(go_to(1), go_to(2)+1, agv_list(i, 3))=d_i(go_to(1), go_to(2)+1, agv_list(i, 3))-1/agv_v;   % Decrease the pheromone
    if (d_i(go_to(1), go_to(2)+1, agv_list(i, 3))<min_v)    % Don't exeed minimal pheromone level
        d_i(go_to(1), go_to(2)+1, agv_list(i, 3))=min_v;
    end
   
         d_i(go_to(1), go_to(2)-1, agv_list(i, 3))=d_i(go_to(1), go_to(2)-1, agv_list(i, 3))-1/agv_v;   % Decrease the pheromone
    if (d_i(go_to(1), go_to(2)-1, agv_list(i, 3))<min_v)    % Don't exeed minimal pheromone level
        d_i(go_to(1), go_to(2)-1, agv_list(i, 3))=min_v;
    end
    
        d_i(go_to(1), go_to(2), agv_list(i, 3))=0;  % No pheromone at AGV's position
end