%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Function:               f_circular_arrangement
%  Description:           Builds the shop layout  with:
%                                       5 machines
%                                       4 loading bays
%                                       6 unloading bays
%                                       10   AGVs
%                                       circular_arrangement
%                                       
%  Dependencies:      none                                             
%  Author:                     Stefan Bracher
%  Date:                        13.04.2007
%  Status:                      REL
%  
%  Syntaxe:                  handles= f_circular_arrangement(handles)
%                                                                    
%  Input:                       handles.*.*
%
%
%  Output:                    handles.t:                Elapsed simulation time
%                                   handles.o:              Map of the obstacles:
%                                                                    2D Matrix, 1=0bstacle, 0=no obstacle
%                                   handles.d_i:          Pheromone maps
%                                                                   (2+n)D Matrix, n=number of different pheromones
%                                  handles.lbay_list:  Loading bay list
%                                                                    n*[x-position, y-position, time_until loaded, blocked time]
%                                                                    n= number of loading bays (details see loading_bay.m)                         
%                                   handles.ulbay_list:  Unloading bay list
%                                                                    n*[x-position, y-position, time_until unloaded, treated units, idle time]
%                                                                    n= number of loading bays (details see uloading_bay.m)                           
%                                   handles.machine_list:  Machine
%                                                                    n*[x-position, y-position, status, time until job completion, idle time, blocked time]
%                                                                    n= number of machines (details see machine.m)                    
%                                   handles.agv_list:  AGV list
 %                                                                  n*[x-position, y-position, status, idle time]
 %                                                                  n=number of AGVs (details see agv.m)   
 %                                  handles.*.*            All the other  unchanged members of handles
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function handles=f_circular_arrangement(handles)

handles.t=0;                                    % Elapsed simulation time=0

handles.o=zeros(40, 40);             % Making a 40x40 obstacle matrix. 0=free, 1=obstacle

% Put walls
handles.o(1:40 ,1:2)=1;   
handles.o(1:40, 39:40)=1;    
handles.o(1:2, 1:40)=1;
handles.o(39:40, 1:40)=1;

% Initiate 40x40 fields for 3 different pheromones
handles.d_i(1:40, 1:40, 1)=zeros(40); 
handles.d_i(1:40, 1:40, 2)=zeros(40);
handles.d_i(1:40, 1:40, 3)=zeros(40);

% Loading bay placement
handles.lbay_list=[];                                       % Clear old placements
handles.lbay_list(1, 1:4)=[16, 14, 0, 0];         % Loading bay 1
handles.o(15:17, 15:17)=1;                               %   Obstruction by Loading bay 1
handles.lbay_list(2, 1:4)=[26, 14, 0, 0];         % Loading bay 2
handles.o(25:27, 15:17)=1;                               %   Obstruction by Loading bay 2
handles.lbay_list(3, 1:4)=[16, 28, 0, 0];         % Loading bay 3
handles.o(15:17, 25:27)=1;                               %   Obstruction by Loading bay 3
handles.lbay_list(4, 1:4)=[26, 28, 0, 0];       % Loading bay 4
handles.o(25:27, 25:27)=1;                           %   Obstruction by Loading bay 4

%Unloading bay placement
handles.ulbay_list=[];                                            % Clear old placements
 handles.ulbay_list(1, 1:5)=[19, 10, 0, 0, 0];     % Unloading bay 1
 handles.o(18:20, 7:9)=1;                               % Obstruction by Unloading bay 1
 handles.ulbay_list(2, 1:5)=[23, 10, 0, 0, 0];     % Unloading bay 2
 handles.o(22:24, 7:9)=1;                                % Obstruction by Unloading bay 2
handles.ulbay_list(3, 1:5)=[19, 32, 0, 0, 0];     % Unloading bay 3
 handles.o(18:20, 33:35)=1;                                % Obstruction by Unloading bay 3
handles.ulbay_list(4, 1:5)=[23, 32, 0, 0, 0];     % Unloading bay 4
 handles.o(22:24, 33:35)=1;                               % Obstruction by Unloading bay 4
handles.ulbay_list(5, 1:5)=[11, 18, 0, 0, 0];     % Unloading bay 5
handles.o(8:10, 17:19)=1;                                % Obstruction by Unloading bay 5
handles.ulbay_list(6, 1:5)=[11, 24, 0, 0, 0];     % Unloading bay 6
handles.o(8:10, 23:25)=1;                                % Obstruction by Unloading bay 6

% Machine placement
handles.machine_list=[];                                        % Clear old placements
handles.machine_list(1, 1:6)=[16, 10, 0, 0, 0, 0];   % Machine 1
handles.o(13:15, 9:11)=1;                                             % Obstruction by Machine 1
handles.machine_list(2, 1:6)=[26, 10, 0, 0, 0, 0];   % Machine 2
handles.o(27:29, 9:11)=1;                                           % Obstruction by Machine 2
handles.machine_list(3, 1:6)=[16, 32, 0, 0, 0, 0];  % Machine 3
handles.o(13:15, 31:33)=1;                                         % Obstruction by Machine 3
handles.machine_list(4, 1:6)=[26, 32, 0, 0, 0, 0];  % Machine 4
handles.o(27:29, 31:33)=1;                                          % Obstruction by Machine 4
handles.machine_list(5, 1:6)=[29, 21, 0, 0, 0, 0];   % Machine 5
handles.o(30:32, 20:22)=1;                                           % Obstruction by Machine 5

% AGV placement
handles.agv_list=[];                                          % Clear old placements
handles.agv_list(1, 1:4)=[4, 5, 1, 0];          % AGV 1, idle
handles.agv_list(2, 1:4)=[6, 5, 1, 0];          % AGV 2, idle
handles.agv_list(3, 1:4)=[8, 5, 1, 0];          % AGV 3, idle
handles.agv_list(4, 1:4)=[10, 5, 1, 0];          % AGV 4, idle
handles.agv_list(5, 1:4)=[12, 5, 1, 0];          % AGV 5, idle
handles.agv_list(6, 1:4)=[14, 5, 1, 0];          % AGV 6, idle
handles.agv_list(7, 1:4)=[16, 5, 1, 0];          % AGV 7, idle
handles.agv_list(8, 1:4)=[18, 5, 1, 0];          % AGV 8, idle
handles.agv_list(9, 1:4)=[20, 5, 1, 0];          % AGV 9, idle
handles.agv_list(10, 1:4)=[22, 5, 1, 0];          % AGV 10, idle








