%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Function:               Optimized Floormap
%  Description:           Builds the shop layout  with:
%                                       10 machines
%                                       12 loading bays
%                                       12 unloading bays
%                                       20   AGVs
%                                       optimized layout
%  Dependencies:      none                                             
%  Author:                     Stefan Bracher
%  Date:                        13.04.2007
%  Status:                      REL
%  
%  Syntaxe:                  handles=optimized_floormap(handles)
%                                                                    
%  Input:                       handles.*.*
%
%
%  Output:                    handles.t:                Elapsed simulation time
%                                   handles.o:              Map of the obstacles:
%                                                                    2D Matrix, 1=0bstacle, 0=no obstacle
%                                   handles.d_i:          Pheromone maps
%                                                                   (2+n)D Matrix, n=number of different pheromones
%                                  handles.lbay_list:  Loading bay list
%                                                                    n*[x-position, y-position, time_until loaded, blocked time]
%                                                                    n= number of loading bays (details see loading_bay.m)                         
%                                   handles.ulbay_list:  Unloading bay list
%                                                                    n*[x-position, y-position, time_until unloaded, treated units, idle time]
%                                                                    n= number of loading bays (details see uloading_bay.m)                           
%                                   handles.machine_list:  Machine
%                                                                    n*[x-position, y-position, status, time until job completion, idle time, blocked time]
%                                                                    n= number of machines (details see machine.m)                    
%                                   handles.agv_list:  AGV list
 %                                                                  n*[x-position, y-position, status, idle time]
 %                                                                  n=number of AGVs (details see agv.m)   
 %                                  handles.*.*            All the other  unchanged members of handles
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function handles=optimized_floormap(handles)

handles.t=0;                                    % Elapsed simulation time=0

handles.o=ones(40, 40);             % Making a 40x40 obstacle matrix. 0=free, 1=obstacle

% Put paths
handles.o(12:29 ,15:17)=0;   
handles.o(12:29, 24:26)=0;    
handles.o(24:26, 18:23)=0;
handles.o(15:17, 18:23)=0;
handles.o(19:22, 6:14)=0;
handles.o(19:22, 27:35)=0;

% Initiate 40x40 fields for 3 different pheromones
handles.d_i(1:40, 1:40, 1)=zeros(40); 
handles.d_i(1:40, 1:40, 2)=zeros(40);
handles.d_i(1:40, 1:40, 3)=zeros(40);

% Loading bay placement
handles.lbay_list=[];                                       % Clear old placements
handles.lbay_list(1, 1:4)=[19, 17, 0, 0];         % Loading bay 1
handles.lbay_list(2, 1:4)=[22, 17, 0, 0];         % Loading bay 2
handles.lbay_list(3, 1:4)=[19, 24, 0, 0];         % Loading bay 3
handles.lbay_list(4, 1:4)=[22, 24, 0, 0];       % Loading bay 4
handles.lbay_list(5, 1:4)=[19, 6, 0, 0];       % Loading bay 5
handles.lbay_list(6, 1:4)=[19, 35, 0, 0];       % Loading bay 6
handles.lbay_list(7, 1:4)=[21, 6, 0, 0];       % Loading bay 7
handles.lbay_list(8, 1:4)=[21, 35, 0, 0];       % Loading bay 8
handles.lbay_list(9, 1:4)=[15, 22, 0, 0];       % Loading bay 9
handles.lbay_list(10, 1:4)=[26, 19, 0, 0];       % Loading bay 10
% handles.lbay_list(11, 1:4)=[33, 15, 0, 0];       % Loading bay 11
% handles.lbay_list(12, 1:4)=[37, 15, 0, 0];       % Loading bay 12



%Unloading bay placement
handles.ulbay_list=[];                                            % Clear old placements
handles.ulbay_list(1, 1:5)=[19, 10, 0, 0, 0];     % Unloading bay 1
handles.ulbay_list(2, 1:5)=[22, 10, 0, 0, 0];     % Unloading bay 2
handles.ulbay_list(3, 1:5)=[19, 31, 0, 0, 0];     % Unloading bay 3
handles.ulbay_list(4, 1:5)=[22, 31, 0, 0, 0];     % Unloading bay 4
handles.ulbay_list(5, 1:5)=[15, 15, 0, 0, 0];     % Unloading bay 5
handles.ulbay_list(6, 1:5)=[26, 15, 0, 0, 0];     % Unloading bay 6
handles.ulbay_list(7, 1:5)=[15, 26, 0, 0, 0];     % Unloading bay 7
handles.ulbay_list(8, 1:5)=[26, 26, 0, 0, 0];     % Unloading bay 8
handles.ulbay_list(9, 1:5)=[12, 16, 0, 0, 0];     % Unloading bay 9
handles.ulbay_list(10, 1:5)=[29, 25, 0, 0, 0];     % Unloading bay 10
% handles.ulbay_list(11, 1:5)=[33, 35, 0, 0, 0];     % Unloading bay 11
% handles.ulbay_list(12, 1:5)=[37, 35, 0, 0, 0];     % Unloading bay 12

% Machine placement
handles.machine_list=[];                                        % Clear old placements
handles.machine_list(1, 1:6)=[17, 15, 0, 0, 0, 0];   % Machine 1
handles.machine_list(2, 1:6)=[24, 15, 0, 0, 0, 0];   % Machine 2
handles.machine_list(3, 1:6)=[17, 26, 0, 0, 0, 0];  % Machine 3
handles.machine_list(4, 1:6)=[24, 26, 0, 0, 0, 0];  % Machine 4
handles.machine_list(5, 1:6)=[19, 7, 0, 0, 0, 0];   % Machine 5
handles.machine_list(6, 1:6)=[22, 7, 0, 0, 0, 0];    % Machine 6
handles.machine_list(7, 1:6)=[19, 34, 0, 0, 0, 0];     % Machine 7
handles.machine_list(8, 1:6)=[22, 34, 0, 0, 0, 0];   % Machine 8
handles.machine_list(9, 1:6)=[13, 17, 0, 0, 0, 0];    % Machine 9
handles.machine_list(10, 1:6)=[28, 24, 0, 0, 0, 0];  % Machine 10


% AGV placement
handles.agv_list=[];                                          % Clear old placements
handles.agv_list(1, 1:4)=[16, 16, 1, 0];          % AGV 1, idle
handles.agv_list(2, 1:4)=[16, 18, 1, 0];          % AGV 2, idle
handles.agv_list(3, 1:4)=[16, 20, 1, 0];          % AGV 3, idle
handles.agv_list(4, 1:4)=[16, 22, 1, 0];          % AGV 4, idle
handles.agv_list(5, 1:4)=[16, 23, 1, 0];          % AGV 5, idle
handles.agv_list(6, 1:4)=[20, 10, 1, 0];          % AGV 6, idle
handles.agv_list(7, 1:4)=[20, 11, 1, 0];          % AGV 7, idle
handles.agv_list(8, 1:4)=[20, 12, 1, 0];          % AGV 8, idle
handles.agv_list(9, 1:4)=[20, 13, 1, 0];          % AGV 9, idle
handles.agv_list(10, 1:4)=[20, 14, 1, 0];          % AGV 10, idle
handles.agv_list(11, 1:4)=[20, 25, 1, 0];          % AGV 11, idle
handles.agv_list(12, 1:4)=[20, 26, 1, 0];          % AGV 12, idle
handles.agv_list(13, 1:4)=[20, 27, 1, 0];          % AGV 13, idle
handles.agv_list(14, 1:4)=[20, 28, 1, 0];          % AGV 14, idle
handles.agv_list(15, 1:4)=[20, 29, 1, 0];          % AGV 15, idle
handles.agv_list(16, 1:4)=[25, 16, 1, 0];          % AGV 16, idle
handles.agv_list(17, 1:4)=[25, 18, 1, 0];          % AGV 17, idle
handles.agv_list(18, 1:4)=[25, 20 1, 0];          % AGV 18, idle
handles.agv_list(19, 1:4)=[25, 22, 1, 0];          % AGV 19, idle
handles.agv_list(20, 1:4)=[25, 24, 1, 0];          % AGV 20, idle








